@@ -25,11 +25,13 @@ namespace driver
     extern ze_dditable_driver_t pCore;
     extern zet_dditable_driver_t pTools;
     extern zes_dditable_driver_t pSysman;
+    extern zer_dditable_driver_t pRuntime;
     struct __zedlllocal BaseNullHandle : ze_handle_t {
         BaseNullHandle() {
             pCore = &driver::pCore;
             pTools = &driver::pTools;
             pSysman = &driver::pSysman;
+            pRuntime = &driver::pRuntime;
         }
     };
     ///////////////////////////////////////////////////////////////////////////////
@@ -41,8 +43,9 @@ namespace driver
         ze_dditable_t   zeDdiTable = {};
         zet_dditable_t  zetDdiTable = {};
         zes_dditable_t  zesDdiTable = {};
+        zer_dditable_t  zerDdiTable = {};
         std::vector<BaseNullHandle*> globalBaseNullHandle;
-	bool ddiExtensionRequested = false;
+	bool ddiExtensionSupported = false;
 	std::vector<char *> env_vars{};
         context_t();
         ~context_t();
@@ -50,7 +53,7 @@ namespace driver
         void* get( void )
         {
             static uint64_t count = 0x80800000 >> ZEL_NULL_DRIVER_ID;
-            if (ddiExtensionRequested) {
+            if (ddiExtensionSupported) {
                 globalBaseNullHandle.push_back(new BaseNullHandle());
                 return reinterpret_cast<void*>(globalBaseNullHandle.back());
             } else {
@@ -61,6 +64,11 @@ namespace driver
 	char *setenv_var_with_driver_id(const std::string &key, uint32_t driverId);
     };
 
+    ze_result_t ZE_APICALL zerGetLastErrorDescription(const char **ppString);
+    uint32_t ZE_APICALL zerTranslateDeviceHandleToIdentifier(ze_device_handle_t hDevice);
+    ze_device_handle_t ZE_APICALL zerTranslateIdentifierToDeviceHandle(uint32_t identifier);
+    ze_context_handle_t ZE_APICALL zerGetDefaultContext(void);
+    
     extern context_t context;
 } // namespace driver
 
