@@ -1,6 +1,6 @@
 /*
  *
- * Copyright (C) 2020-2021 Intel Corporation
+ * Copyright (C) 2020-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -28,7 +28,7 @@ zeLoaderInit();
 
 ///////////////////////////////////////////////////////////////////////////////
 /// @brief Exported function for verifying usable L0 Drivers for Loader to report
-///
+/// @deprecated This function is deprecated and will be removed in a future release.
 /// @returns
 ///     - ::ZE_RESULT_SUCCESS
 ///     - ::ZE_RESULT_ERROR_UNINITIALIZED
@@ -37,11 +37,17 @@ zelLoaderDriverCheck(ze_init_flags_t flags, ze_init_driver_type_desc_t* desc, ze
 
 
 ///////////////////////////////////////////////////////////////////////////////
-/// @brief Internal function for Setting the ddi table for the Tracing Layer.
+/// @brief Internal function for Setting the ZE ddi table for the Tracing Layer.
 ///
 ZE_DLLEXPORT ze_result_t ZE_APICALL
 zelLoaderTracingLayerInit(std::atomic<ze_dditable_t *> &zeDdiTable);
 
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Internal function for Setting the ZER ddi table for the Tracing Layer.
+///
+ZE_DLLEXPORT ze_result_t ZE_APICALL
+zelLoaderZerTracingLayerInit(std::atomic<zer_dditable_t *> &zerDdiTable);
+
 
 ///////////////////////////////////////////////////////////////////////////////
 /// @brief Exported function for getting tracing lib handle
